# Easierfile

[![PyPI Latest Release](https://img.shields.io/pypi/v/easierfile.svg)](https://pypi.org/project/easierfile/)
[![Package Status](https://img.shields.io/pypi/status/easierfile.svg)](https://pypi.org/project/easierfile/)
[![License](https://img.shields.io/pypi/l/easierfile.svg)](https://github.com/leoweyr/Python-Easierfile/blob/main/LICENSE)
[![Downloads](https://static.pepy.tech/personalized-badge/easierfile?period=total&units=international_system&left_color=grey&right_color=green&left_text=pypi%20downloads)](https://pepy.tech/project/easierfile)

An easier-to-use Python package that object-oriented encapsulates Python traditional built-in file operations. It's also easier than `easygui`. o((>ω< ))o

## 💿Obtainment

The source code is currently hosted on Github at: https://github.com/leoweyr/Python-Easierfile

Binary installers for the latest released version are available at the [Python Package Index (PyPI)](https://pypi.org/project/easierfile/).

```sh
# PyPI
pip install easierfile
```

## 🔗Dependencies

- [Dynoptimdict - A dynamic data dict class that inherits and overrides the built-in dict class for special purposes. That provides real-time access to dynamic data, while still allowing the option to get only the specified data without calculating all. It adheres to the concept of program optimization which avoids loading if not used, saving both memory and time](https://github.com/leoweyr/Python-Dynoptimdict)
- [Chardet - The universal character encoding detector](https://github.com/chardet/chardet)

## ⚖️License

[MIT](https://github.com/leoweyr/Python-Easierfile/blob/main/LICENSE)

## 📗Documentation

The documentation is hosted on Github repository: https://github.com/leoweyr/Python-Easierfile/blob/main/doc